TODO
=======================================================================

- Remove matplotlib from imports done by mib2hdfConvert package to decrease load time and debug volume.
- Make sure we can collect and process mib files which are not in a material subdirectory.
- Add unit tests for the mib_convert task.
  